| Title: | 'Rapidjson' C++ Header Files |
|---|---|
| Description: | Provides JSON parsing capability through the 'Rapidjson' 'C++' header-only library. |
| Authors: | David Cooley [aut, cre], Milo Yip [ctb] (Author of c++ rapidjson library, provided through THL A29 Limited, a Tencent company), Alexander Chemeris [ctb] (Author of c++ msinttypes library) |
| Maintainer: | David Cooley <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.2.1 |
| Built: | 2026-05-23 07:52:30 UTC |
| Source: | https://github.com/cran/rapidjsonr |
Provides JSON parsing capability through the 'Rapidjson' 'C++' header-only library.
Maintainer: David Cooley [email protected]
Other contributors:
Milo Yip (Author of c++ rapidjson library, provided through THL A29 Limited, a Tencent company) [contributor]
Alexander Chemeris (Author of c++ msinttypes library) [contributor]
## Not run: # Include a dependency to rapidjsonr inside a cpp file // [[Rcpp::depends(rapidjsonr)]] include <Rcpp.h> ## End(Not run)## Not run: # Include a dependency to rapidjsonr inside a cpp file // [[Rcpp::depends(rapidjsonr)]] include <Rcpp.h> ## End(Not run)