Welcome to ClientVPS Mirrors

Help for package rapidjsonr
Type: Package
Title: 'Rapidjson' C++ Header Files
Version: 1.2.1
Date: 2025-11-23
Description: Provides JSON parsing capability through the 'Rapidjson' 'C++' header-only library.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.1
SystemRequirements: GNU make
NeedsCompilation: no
Packaged: 2025-11-23 16:12:43 UTC; david
Author: David Cooley [aut, cre], Milo Yip [ctb] (Author of c++ rapidjson library, provided through THL A29 Limited, a Tencent company), Alexander Chemeris [ctb] (Author of c++ msinttypes library)
Maintainer: David Cooley <dcooley@symbolix.com.au>
Repository: CRAN
Date/Publication: 2025-11-24 08:50:07 UTC

Proivdes JSON parsing capability through the 'Rapidjson' 'C++' header-only library.

Description

Provides JSON parsing capability through the 'Rapidjson' 'C++' header-only library.

Author(s)

Maintainer: David Cooley dcooley@symbolix.com.au

Other contributors:

Examples

## Not run: 

# Include a dependency to rapidjsonr inside a cpp file
// [[Rcpp::depends(rapidjsonr)]]
include <Rcpp.h>

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.